@@ -40,6 +40,7 @@ import (
 	"github.com/blacktop/go-plist"
 	"github.com/blacktop/ipsw/internal/commands/ent"
 	"github.com/blacktop/ipsw/internal/utils"
+	"github.com/blacktop/ipsw/pkg/info"
 	"github.com/fatih/color"
 	"github.com/sergi/go-diff/diffmatchpatch"
 	"github.com/spf13/cobra"
@@ -65,6 +66,8 @@ func init() {
 	entCmd.Flags().BoolP("diff", "d", false, "Diff entitlements")
 	entCmd.Flags().BoolP("md", "m", false, "Markdown style output")
 	entCmd.Flags().Bool("ui", false, "Show entitlements UI")
+	entCmd.Flags().String("ui-host", "localhost", "UI host to server on")
+	entCmd.Flags().Int("ui-port", 3993, "UI port to server on")
 	viper.BindPFlag("ent.ipsw", entCmd.Flags().Lookup("ipsw"))
 	viper.BindPFlag("ent.input", entCmd.Flags().Lookup("input"))
 	viper.BindPFlag("ent.key", entCmd.Flags().Lookup("key"))
@@ -75,6 +78,8 @@ func init() {
 	viper.BindPFlag("ent.diff", entCmd.Flags().Lookup("diff"))
 	viper.BindPFlag("ent.md", entCmd.Flags().Lookup("md"))
 	viper.BindPFlag("ent.ui", entCmd.Flags().Lookup("ui"))
+	viper.BindPFlag("ent.ui-host", entCmd.Flags().Lookup("ui"))
+	viper.BindPFlag("ent.ui-port", entCmd.Flags().Lookup("ui"))
 	entCmd.MarkFlagsMutuallyExclusive("key", "val", "ui")
 	entCmd.Flags().MarkHidden("ui")
 }
@@ -122,6 +127,8 @@ var entCmd = &cobra.Command{
 		// check flags
 		if len(dbFolder) == 0 && len(ipsws) == 0 && len(inputs) == 0 {
 			return fmt.Errorf("must supply either --db, --ipsw or --input")
+		} else if showUI && doDiff || len(ipsws) > 1 {
+			return fmt.Errorf("cannot use --ui with --diff OR multiple IPSWs")
 		}
 		color.NoColor = viper.GetBool("no-color") || onlyFiles
 
@@ -185,7 +192,26 @@ var entCmd = &cobra.Command{
 		}
 
 		if showUI {
-			panic("not implemented")
+			var version string
+			if len(ipsws) == 1 {
+				if i, err := info.Parse(ipsws[0]); err == nil {
+					version = fmt.Sprintf("for %s (%s)",
+						i.Plists.BuildManifest.ProductVersion,
+						i.Plists.BuildManifest.ProductBuildVersion)
+				}
+			}
+			db := make(map[string]string)
+			for f, e := range entDBs[0] {
+				if len(e) == 0 {
+					continue
+				}
+				db[f] = e
+			}
+			return ent.UI(db, &ent.Config{
+				Version: version,
+				Host:    viper.GetString("ent.host"),
+				Port:    viper.GetInt("ent.port"),
+			})
 		} else if doDiff { // DIFF ENTITLEMENTS
 			if len(searchFile) > 0 { // DIFF MACHO'S ENTITLEMENTS
 				dmp := diffmatchpatch.New()
