@@ -61,7 +61,7 @@ func init() {
 // aeaCmd represents the ane command
 var aeaCmd = &cobra.Command{
 	Use:   "aea",
-	Short: "Parse ANE1 DMGs",
+	Short: "Parse AEA1 DMGs",
 	Args:  cobra.ExactArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) (err error) {
 		var pemData []byte
