@@ -52,7 +52,7 @@ var ibootCmd = &cobra.Command{
 	Use:     "iboot <IBOOT_BIN>",
 	Aliases: []string{"ib"},
 	Short:   "Dump firmwares",
-	Args:    cobra.MinimumNArgs(1),
+	Args:    cobra.ExactArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
 		var name string
 
