@@ -304,7 +304,7 @@ type Rebase struct {
 	CacheFileOffset uint64 `json:"cache_file_offset,omitempty"`
 	CacheVMAddress  uint64 `json:"cache_vm_address,omitempty"`
 	Target          uint64 `json:"target,omitempty"`
-	Pointer         any    `json:"pointer,omitempty"`
+	Pointer         uint64 `json:"pointer,omitempty"`
 	Symbol          string `json:"symbol,omitempty"`
 }
 
